@@ -12,35 +12,54 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
+#include "audioclock.h"
+#include "audiofilter.h"
+#include "audiosink.h"
+#include "audiosrc.h"
+#include "baseaudiosink.h"
+#include "baseaudiosrc.h"
+#include "basesink.h"
+#include "basesrc.h"
+#include "basetransform.h"
 #include "bin.h"
 #include "buffer.h"
 #include "bus.h"
 #include "caps.h"
+#include "cddabasesrc.h"
 #include "childproxy.h"
 #include "clock.h"
-#include "element.h"
+#include "colorbalancechannel.h"
+#include "colorbalance.h"
 #include "elementfactory.h"
+#include "element.h"
 #include "enums.h"
 #include "error.h"
 #include "event.h"
 #include "filter.h"
 #include "format.h"
 #include "ghostpad.h"
-#include "index.h"
 #include "indexfactory.h"
+#include "index.h"
 #include "interface.h"
 #include "iterator.h"
 #include "message.h"
+#include "mixer.h"
+#include "mixeroptions.h"
+#include "mixertrack.h"
+#include "navigation.h"
 #include "object.h"
 #include "pad.h"
 #include "padtemplate.h"
 #include "parse.h"
 #include "pipeline.h"
-#include "plugin.h"
 #include "pluginfeature.h"
+#include "plugin.h"
 #include "preset.h"
+#include "propertyprobe.h"
+#include "pushsrc.h"
 #include "query.h"
 #include "registry.h"
+#include "ringbuffer.h"
 #include "segment.h"
 #include "structure.h"
 #include "systemclock.h"
@@ -48,36 +67,73 @@
 #include "tagsetter.h"
 #include "task.h"
 #include "taskpool.h"
+#include "tunerchannel.h"
+#include "tuner.h"
+#include "tunernorm.h"
+#include "typefindfactory.h"
+#include "typefind.h"
 #include "urihandler.h"
 #include "value.h"
-#include "xml.h"
-#include "basesink.h"
-#include "basesrc.h"
-#include "basetransform.h"
-#include "pushsrc.h"
-#include "audioclock.h"
-#include "audiofilter.h"
-#include "audiosink.h"
-#include "audiosrc.h"
-#include "baseaudiosink.h"
-#include "baseaudiosrc.h"
-#include "cddabasesrc.h"
-#include "ringbuffer.h"
-#include "videosink.h"
-#include "colorbalance.h"
-#include "colorbalancechannel.h"
-#include "mixer.h"
-#include "mixeroptions.h"
-#include "mixertrack.h"
-#include "navigation.h"
-#include "propertyprobe.h"
-#include "tuner.h"
-#include "tunerchannel.h"
-#include "tunernorm.h"
-#include "typefind.h"
-#include "typefindfactory.h"
 #include "videoorientation.h"
+#include "videosink.h"
+#include "xml.h"
 #include "xoverlay.h"
+#include "adder.h"
+#include "alsamixer.h"
+#include "alsasink.h"
+#include "alsasrc.h"
+#include "audioconvert.h"
+#include "audioresample.h"
+#include "audiotestsrc.h"
+#include "capsfilter.h"
+#include "cdparanoiasrc.h"
+#include "clockoverlay.h"
+#include "decodebin2.h"
+#include "decodebin.h"
+#include "fakesink.h"
+#include "fakesrc.h"
+#include "fdsink.h"
+#include "fdsrc.h"
+#include "ffmpegcolorspace.h"
+#include "filesink.h"
+#include "filesrc.h"
+#include "gdpdepay.h"
+#include "gdppay.h"
+#include "giosink.h"
+#include "giosrc.h"
+#include "giostreamsink.h"
+#include "giostreamsrc.h"
+#include "identity.h"
+#include "multifdsink.h"
+#include "multiqueue.h"
+#include "oggdemux.h"
+#include "oggmux.h"
+#include "playbin2.h"
+#include "playbin.h"
+#include "queue.h"
+#include "tcpclientsink.h"
+#include "tcpclientsrc.h"
+#include "tcpserversink.h"
+#include "tcpserversrc.h"
+#include "tee.h"
+#include "textoverlay.h"
+#include "textrender.h"
+#include "theoradec.h"
+#include "theoraenc.h"
+#include "theoraparse.h"
+#include "timeoverlay.h"
+#include "typefindelement.h"
+#include "uridecodebin.h"
+#include "videorate.h"
+#include "videoscale.h"
+#include "videotestsrc.h"
+#include "volume.h"
+#include "vorbisdec.h"
+#include "vorbisenc.h"
+#include "vorbisparse.h"
+#include "vorbistag.h"
+#include "ximagesink.h"
+#include "xvimagesink.h"
 
 extern "C"
 {
