@@ -30,14 +30,14 @@ int main(int argc, char* argv[])
 
   Glib::RefPtr<Gst::FileSrc> filesrc = Gst::FileSrc::create();
 
-  if (filesrc)
+  if(filesrc)
     std::cout << "filesrc is valid." << std::endl;
   else
     std::cout << "filesrc is invalid." << std::endl;
 
   gulong mmapsize = 0;
   GstFileSrc* obj = filesrc->gobj();
-  g_object_get(obj, "mmapsize", &mmapsize, NULL);
+  g_object_get(obj, "mmapsize", &mmapsize, (void*)0);
 
   std::cout << "mmapsize = "  << mmapsize << std::endl;
 
